import { BigNumber } from 'ethers';
import { IDIDDocument, IResolver, DelegateTypes, IPublicKey, IServiceEndpoint, IAuthentication, DocumentSelector, IDIDLogData } from '@ew-did-registry/did-resolver-interface';
import { IDIDDocumentLite } from './interface';
declare class DIDDocumentLite implements IDIDDocumentLite {
    did: string;
    private resolver;
    /**
     * @param {string} did - entity identifier, which is associated with DID Document
     * @param {IResolver} resolver - resolver exposing read functionality of DID Document
     */
    constructor(did: string, resolver: IResolver);
    /**
     * Returns the current owner for certain DID.
     * If owner not assigned explicitly than identity is the owner of itself
     *
     * @param {string} did
     * @returns {Promise<string>}
     */
    getController(did?: string): Promise<string>;
    /**
     * Checks if the delegate is present for a particular DID.
     *
     * @param {DelegateTypes} delegateType
     * @param {string} delegateDID
     * @param {string} did
     * @returns {Promise<boolean>}
     */
    isValidDelegate(delegateType: DelegateTypes, delegateDID: string, did?: string): Promise<boolean>;
    /**
     * Finds first attribute which satisfies filter
     *
     * @param selector {{ [attr: string]: { [prop: string]: string } }} object used
     *  to describe part of the document. `attr` is one of standard DID attributes
     *  like `publicKey`, `serviceEndpoints` or `authentication` and `prop` - properties
     *  of this attribute such as `type` or `value`
     * @param did {string}
     *
     * @returns {object | null}
     */
    readAttribute(selector: DocumentSelector, did?: string): Promise<IPublicKey | IServiceEndpoint | IAuthentication | undefined>;
    /**
     * Returns document of the given `did`
     *
     * @param did {string}
     */
    read(did?: string): Promise<IDIDDocument>;
    ownerPubKey(did?: string): Promise<string | undefined>;
    lastBlock(did: string): Promise<BigNumber>;
    readFromBlock(did: string, from: BigNumber): Promise<IDIDLogData>;
    fromLogs(logs: IDIDLogData[], did?: string): IDIDDocument;
}
export { IDIDDocumentLite, DIDDocumentLite };
